Preprocessing
==============

This module provides preprocessing utilities including autoencoder-based feature extraction.

.. currentmodule:: torch_concepts.data.preprocessing.autoencoder

Summary
-------

**Autoencoder Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   SimpleAutoencoder
   AutoencoderTrainer

**Preprocessing Functions**

.. autosummary::
   :toctree: generated
   :nosignatures:

   extract_embs_from_autoencoder


Class Documentation
-------------------

.. autoclass:: torch_concepts.data.preprocessing.autoencoder.SimpleAutoencoder
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.preprocessing.autoencoder.AutoencoderTrainer
   :members:
   :undoc-members:
   :show-inheritance:


Function Documentation
----------------------

.. autofunction:: torch_concepts.data.preprocessing.autoencoder.extract_embs_from_autoencoder
